==> testsuite-3.0.57-beta1.tar.gz: testsuite/modules/list_packages/src/Controller/ListPackagesController.php <==
<?php

namespace Drupal\list_packages\Controller;

use Drupal\Component\Utility\UrlHelper;
use Drupal\Component\Utility\Xss;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\PagerSelectExtender;
use Drupal\Core\Database\Query\TableSortExtender;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Link;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\list_packages\GetNpmRegisteryClient;
use Drupal\list_packages\GetPackagistClient;
use Drupal\testsuite\BaseTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Returns responses for dblog routes.
 */
class ListPackagesController extends ControllerBase {
  use BaseTrait;

  /**
   * The database service.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * The user storage.
   *
   * @var \Drupal\user\UserStorageInterface
   */
  protected $userStorage;

  /**
   * The packagist client.
   *
   * @var \Drupal\list_packages\GetPackagistClient
   */
  protected $getPackagistClient;

  /**
   * The NPM Registery client.
   *
   * @var \Drupal\list_packages\GetNpmRegisteryClient
   */
  protected $getNpmRegisteryClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('database'),
          $container->get('module_handler'),
          $container->get('date.formatter'),
          $container->get('form_builder'),
          $container->get('list_packages.packagist_client.service'),
          $container->get('list_packages.npm_client.service')
      );
  }

  /**
   * Constructs a DbLogController object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   A database connection.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   A module handler.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   * @param \Drupal\list_packages\GetPackagistClient $get_packagist_client
   *   The form builder service.
   * @param \Drupal\list_packages\GetNpmRegisteryClient $get_npm_registery_client
   *   The form builder service.
   */
  public function __construct(
        Connection $database,
        ModuleHandlerInterface $module_handler,
        DateFormatterInterface $date_formatter,
        FormBuilderInterface $form_builder,
        GetPackagistClient $get_packagist_client,
        GetNpmRegisteryClient $get_npm_registery_client
    ) {
    $this->database = $database;
    $this->moduleHandler = $module_handler;
    $this->dateFormatter = $date_formatter;
    $this->formBuilder = $form_builder;
    $this->getPackagistClient = $get_packagist_client;
    $this->getNpmRegisteryClient = $get_npm_registery_client;
    $this->userStorage = $this->entityTypeManager()->getStorage('user');
  }

  /**
   * Displays a listing of database log messages.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return array
   *   A render array as expected by
   *   \Drupal\Core\Render\RendererInterface::render().
   *
   * @see Drupal\list_packages\Form\ListPackagesClearLogConfirmForm
   * @see Drupal\list_packages\Controller\ListPackagesController::eventDetails()
   */
  public function overview(Request $request) {

    $filter = $this->buildFilterQuery($request);
    $rows = [];

    $this->moduleHandler()->loadInclude('list_packages', 'admin.inc');

    $description = 'This is the report of all the composer packages used in the composer.json file in the root or your Drupal installation.';
    $build = $this->createLegend($description);

    $build['list_packages_filter_form'] = $this->formBuilder()->getForm('Drupal\list_packages\Form\ListPackagesFilterForm');
    $header = [
      [
        'data' => $this->t('Date Created'),
        'field' => 'lpip.created',
        'sort' => 'desc',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      [
        'data' => $this->t('Name'),
        'field' => 'lpip.name',
        'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ],
      [
        'data' => $this->t('Version'),
        'field' => 'lpip.version',
        'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ],
      [
        'data' => $this->t('Latest'),
        'field' => 'lpip.latest',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      [
        'data' => $this->t('Description'),
        'field' => 'lpip.description',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      [
        'data' => $this->t('Vulnerabilities'),
        'field' => 'lpip.if_vulnerability',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
    ];

    /** @var \Drupal\Core\Database\Query\SelectInterface $query */
    $query = $this->database->select('lp_installed_package', 'lpip')
      ->extend(PagerSelectExtender::class)
      ->extend(TableSortExtender::class);
    $query->fields(
      'lpip', [
        'id',
        'name',
        'version',
        'latest',
        'description',
        'if_vulnerability',
        'created',
      ]
    );

    if (!empty($filter['where'])) {
      $query->where($filter['where'], $filter['args']);
    }

    $results = $query
      ->limit(50)
      ->orderByHeader($header)
      ->execute()->fetchAllAssoc('id');

    usort($results, 'comparator');

    foreach ($results as $testItem) {
      $name = Link::fromTextAndUrl(
        Xss::filter($testItem->name), new Url(
          'list_packages.installed_packages_event', ['event_id' => $testItem->id], [
            'attributes' => [
              'title' => Xss::filter($testItem->name),
            ],
          ]
        )
      )->toString();
      $rows[] = [
        'data' => [
          $this->dateFormatter->format($testItem->created, 'short'),
          $name,
          Xss::filter($testItem->version),
          Xss::filter($testItem->latest),
          Xss::filter($testItem->description),
          Markup::create($this->getEmoji($testItem->if_vulnerability)),
        ],
      ];
    }

    $build['list_packages_table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => $this->t('No log messages available.'),
    ];

    $build['list_packages_pager'] = ['#type' => 'pager'];

    return $build;

  }

  /**
   * Displays details about a specific database log message.
   *
   * @param int $event_id
   *   Unique ID of the database log message.
   *
   * @return array
   *   If the ID is located in the Database Logging table, a build array in the
   *   format expected by \Drupal\Core\Render\RendererInterface::render().
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   If no event found for the given ID.
   */
  public function eventDetails($event_id) {
    $testItem = $this->database->query('SELECT [lpip].* FROM {lp_installed_package} [lpip] WHERE [lpip].[id] = :id', [':id' => $event_id])->fetchObject();

    if (empty($testItem)) {
      throw new NotFoundHttpException();
    }

    $build = [];
    $rows = [
      [
      ['data' => $this->t('Date Created'), 'header' => TRUE],
        $this->dateFormatter->format($testItem->created, 'long'),
      ],
      [
      ['data' => $this->t('Name'), 'header' => TRUE],
        Xss::filter($testItem->name),
      ],
      [
      ['data' => $this->t('Type'), 'header' => TRUE],
        $testItem->type,
      ],
      [
      ['data' => $this->t('Vendor'), 'header' => TRUE],
        Xss::filter($testItem->vendor),
      ],
      [
      ['data' => $this->t('Product'), 'header' => TRUE],
        Xss::filter($testItem->product),
      ],
      [
      ['data' => $this->t('Version'), 'header' => TRUE],
        Xss::filter($testItem->version),
      ],
      [
      ['data' => $this->t('Latest'), 'header' => TRUE],
        Xss::filter($testItem->latest),
      ],
      [
      ['data' => $this->t('Abandoned'), 'header' => TRUE],
        $testItem->abandoned == 1 ? "Yes" : "No",
      ],
      [
      ['data' => $this->t('Description'), 'header' => TRUE],
        Xss::filter($testItem->description),
      ],
      [
      ['data' => $this->t('Vulnerability'), 'header' => TRUE],
        Markup::create($this->getEmoji($testItem->if_vulnerability)),
      ],
    ];

    if ($testItem->warning != "") {
      $rows[] = [
        ['data' => $this->t('Warning'), 'header' => TRUE],
        Xss::filter($testItem->warning),
      ];
    }

    if ($testItem->if_vulnerability == 0 || $testItem->if_vulnerability == 1) {
      $vulnerabilityMarkup = "<h3>Listed Vulnerabilitites</h3>";
      if ($testItem->type == 'composer') {
        $vulnerabilityInfo = $this->getPackagistClient->getVulnerabilities($testItem->vendor, strtolower($testItem->product));
        $vulnerabilityMarkup = $this->getVulnerabilityMarkup($vulnerabilityInfo['advisories'][$testItem->vendor . "/" . strtolower($testItem->product)]);
      }
      $rows[] = [
        ['data' => $this->t('Vulnerability Report'), 'header' => TRUE],
        Markup::create($vulnerabilityMarkup),
      ];
    }

    $build['vulnerability_test_item_table'] = [
      '#type' => 'table',
      '#rows' => $rows,
    ];

    return $build;
  }

  /**
   * Builds a markup string for vulnerabilities.
   *
   * @param mixed $vulnerabilities
   *   The vulnerabilitites to be made into markup.
   *
   * @return string
   *   Vulnerabilitites as a markup string
   */
  private function getVulnerabilityMarkup($vulnerabilities) {
    $vulnerabilityMarkup = "";
    if (isset($vulnerabilities)) {
      if (count($vulnerabilities) > 0) {
        foreach ($vulnerabilities as $item) {
          $advisoryId = Xss::filter($item['advisoryId']);
          $vulnerabilityMarkup .= "<p><b>advisoryId:</b> {$advisoryId}</p>";
          $packageName = Xss::filter($item['packageName']);
          $vulnerabilityMarkup .= "<p><b>packageName:</b> {$packageName}</p>";
          $remoteId = Xss::filter($item['remoteId']);
          $vulnerabilityMarkup .= "<p><b>remoteId:</b> {$remoteId}</p>";
          $title = Xss::filter($item['title']);
          $vulnerabilityMarkup .= "<p><b>title:</b> {$title}</p>";
          $link = Link::fromTextAndUrl(
            $item['link'],
            Url::fromUri($item['link'])
          )->toString();
          $vulnerabilityMarkup .= $link;
          $cve = Xss::filter($item['cve']);
          $vulnerabilityMarkup .= "<p><b>cve:</b> {$cve}</p>";
          $affectedVersions = Xss::filter($item['affectedVersions']);
          $vulnerabilityMarkup .= "<p><b>affectedVersions:</b> {$affectedVersions}</p>";
          $source = UrlHelper::filterBadProtocol($item['source']);
          $vulnerabilityMarkup .= "<p><b>source:</b> {$source}</p>";
          $reportedAt = Xss::filter($item['reportedAt']);
          $vulnerabilityMarkup .= "<p><b>reportedAt:</b> {$reportedAt}</p>";
          $composerRepository = UrlHelper::filterBadProtocol($item['composerRepository']);
          $vulnerabilityMarkup .= "<p><b>composerRepository:</b> {$composerRepository}</p>";
          $severity = Xss::filter($item['severity']);
          $vulnerabilityMarkup .= "<p><b>severity:</b> {$severity}</p><br />";
        }
      }
    }

    return $vulnerabilityMarkup;
  }

  /**
   * Builds a query for database log administration filters based on session.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return array|null
   *   An associative array with keys 'where' and 'args' or NULL if there were
   *   no filters set.
   */
  private function buildFilterQuery(Request $request) {
    $session_filters = $request->getSession()->get('list_packages_overview_filter', []);
    if (empty($session_filters)) {
      return;
    }

    $this->moduleHandler()->loadInclude('list_packages', 'admin.inc');

    $filters = list_packages_filters();

    // dd($filters);
    // Build query.
    $where = $args = [];
    foreach ($session_filters as $key => $filter) {
      if ($key != 'action' && $filter != "") {
        $filter_where = [];
        $filter_where[] = $filters[$key]['where'];
        $args[] = $filter;

        if (!empty($filter_where)) {
          $where[] = '(' . implode(' OR ', $filter_where) . ')';
        }
      }
    }
    $where = !empty($where) ? implode(' AND ', $where) : '';

    return [
      'where' => $where,
      'args' => $args,
    ];
  }

}

==> testsuite-3.0.61-beta1.tar.gz: testsuite/modules/list_packages/src/Controller/ListPackagesController.php <==
<?php

namespace Drupal\list_packages\Controller;

use Drupal\Component\Utility\UrlHelper;
use Drupal\Component\Utility\Xss;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Database\Query\PagerSelectExtender;
use Drupal\Core\Database\Query\TableSortExtender;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Link;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\list_packages\GetNpmRegisteryClient;
use Drupal\list_packages\GetPackagistClient;
use Drupal\testsuite\BaseTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

/**
 * Returns responses for dblog routes.
 */
class ListPackagesController extends ControllerBase {
  use BaseTrait;

  /**
   * The database service.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * The date formatter service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $dateFormatter;

  /**
   * The user storage.
   *
   * @var \Drupal\user\UserStorageInterface
   */
  protected $userStorage;

  /**
   * The packagist client.
   *
   * @var \Drupal\list_packages\GetPackagistClient
   */
  protected $getPackagistClient;

  /**
   * The NPM Registery client.
   *
   * @var \Drupal\list_packages\GetNpmRegisteryClient
   */
  protected $getNpmRegisteryClient;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
          $container->get('database'),
          $container->get('module_handler'),
          $container->get('date.formatter'),
          $container->get('form_builder'),
          $container->get('list_packages.packagist_client.service'),
          $container->get('list_packages.npm_client.service')
      );
  }

  /**
   * Constructs a DbLogController object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   A database connection.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   A module handler.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   * @param \Drupal\list_packages\GetPackagistClient $get_packagist_client
   *   The form builder service.
   * @param \Drupal\list_packages\GetNpmRegisteryClient $get_npm_registery_client
   *   The form builder service.
   */
  public function __construct(
    Connection $database,
    ModuleHandlerInterface $module_handler,
    DateFormatterInterface $date_formatter,
    FormBuilderInterface $form_builder,
    GetPackagistClient $get_packagist_client,
    GetNpmRegisteryClient $get_npm_registery_client,
  ) {
    $this->database = $database;
    $this->moduleHandler = $module_handler;
    $this->dateFormatter = $date_formatter;
    $this->formBuilder = $form_builder;
    $this->getPackagistClient = $get_packagist_client;
    $this->getNpmRegisteryClient = $get_npm_registery_client;
    $this->userStorage = $this->entityTypeManager()->getStorage('user');
  }

  /**
   * Displays a listing of database log messages.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return array
   *   A render array as expected by
   *   \Drupal\Core\Render\RendererInterface::render().
   *
   * @see Drupal\list_packages\Form\ListPackagesClearLogConfirmForm
   * @see Drupal\list_packages\Controller\ListPackagesController::eventDetails()
   */
  public function overview(Request $request) {

    $filter = $this->buildFilterQuery($request);
    $rows = [];

    $this->moduleHandler()->loadInclude('list_packages', 'admin.inc');

    $description = 'This is the report of all the composer packages used in the composer.json file in the root or your Drupal installation.';
    $build = $this->createLegend($description);

    $build['list_packages_filter_form'] = $this->formBuilder()->getForm('Drupal\list_packages\Form\ListPackagesFilterForm');
    $header = [
      [
        'data' => $this->t('Date Created'),
        'field' => 'lpip.created',
        'sort' => 'desc',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      [
        'data' => $this->t('Name'),
        'field' => 'lpip.name',
        'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ],
      [
        'data' => $this->t('Version'),
        'field' => 'lpip.version',
        'class' => [RESPONSIVE_PRIORITY_MEDIUM],
      ],
      [
        'data' => $this->t('Latest'),
        'field' => 'lpip.latest',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      [
        'data' => $this->t('Description'),
        'field' => 'lpip.description',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      [
        'data' => $this->t('Vulnerabilities'),
        'field' => 'lpip.if_vulnerability',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
      [
        'data' => $this->t('Vulnerability Count'),
        'field' => 'lpip.vulnerability_count',
        'class' => [RESPONSIVE_PRIORITY_LOW],
      ],
    ];

    /** @var \Drupal\Core\Database\Query\SelectInterface $query */
    $query = $this->database->select('lp_installed_package', 'lpip')
      ->extend(PagerSelectExtender::class)
      ->extend(TableSortExtender::class);
    $query->fields(
      'lpip', [
        'id',
        'name',
        'version',
        'latest',
        'description',
        'if_vulnerability',
        'vulnerability_count',
        'created',
      ]
    );

    if (!empty($filter['where'])) {
      $query->where($filter['where'], $filter['args']);
    }

    $results = $query
      ->limit(50)
      ->orderByHeader($header)
      ->execute()->fetchAllAssoc('id');

    usort($results, 'comparator');

    foreach ($results as $testItem) {
      $name = Link::fromTextAndUrl(
        Xss::filter($testItem->name), new Url(
          'list_packages.installed_packages_event', ['event_id' => $testItem->id], [
            'attributes' => [
              'title' => Xss::filter($testItem->name),
            ],
          ]
        )
      )->toString();
      $rows[] = [
        'data' => [
          $this->dateFormatter->format($testItem->created, 'short'),
          $name,
          Xss::filter($testItem->version),
          Xss::filter($testItem->latest),
          Xss::filter($testItem->description),
          Markup::create($this->getEmoji($testItem->if_vulnerability)),
          Xss::filter($testItem->vulnerability_count),
        ],
      ];
    }

    $build['list_packages_table'] = [
      '#type' => 'table',
      '#header' => $header,
      '#rows' => $rows,
      '#empty' => $this->t('No log messages available.'),
    ];

    $build['list_packages_pager'] = ['#type' => 'pager'];

    return $build;

  }

  /**
   * Displays details about a specific database log message.
   *
   * @param int $event_id
   *   Unique ID of the database log message.
   *
   * @return array
   *   If the ID is located in the Database Logging table, a build array in the
   *   format expected by \Drupal\Core\Render\RendererInterface::render().
   *
   * @throws \Symfony\Component\HttpKernel\Exception\NotFoundHttpException
   *   If no event found for the given ID.
   */
  public function eventDetails($event_id) {
    $testItem = $this->database->query('SELECT [lpip].* FROM {lp_installed_package} [lpip] WHERE [lpip].[id] = :id', [':id' => $event_id])->fetchObject();

    if (empty($testItem)) {
      throw new NotFoundHttpException();
    }

    $build = [];
    $rows = [
      [
      ['data' => $this->t('Date Created'), 'header' => TRUE],
        $this->dateFormatter->format($testItem->created, 'long'),
      ],
      [
      ['data' => $this->t('Name'), 'header' => TRUE],
        Xss::filter($testItem->name),
      ],
      [
      ['data' => $this->t('Type'), 'header' => TRUE],
        $testItem->type,
      ],
      [
      ['data' => $this->t('Vendor'), 'header' => TRUE],
        Xss::filter($testItem->vendor),
      ],
      [
      ['data' => $this->t('Product'), 'header' => TRUE],
        Xss::filter($testItem->product),
      ],
      [
      ['data' => $this->t('Version'), 'header' => TRUE],
        Xss::filter($testItem->version),
      ],
      [
      ['data' => $this->t('Latest'), 'header' => TRUE],
        Xss::filter($testItem->latest),
      ],
      [
      ['data' => $this->t('Abandoned'), 'header' => TRUE],
        $testItem->abandoned == 1 ? "Yes" : "No",
      ],
      [
      ['data' => $this->t('Description'), 'header' => TRUE],
        Xss::filter($testItem->description),
      ],
      [
      ['data' => $this->t('Vulnerability'), 'header' => TRUE],
        Markup::create($this->getEmoji($testItem->if_vulnerability)),
      ],
    ];

    if ($testItem->warning != "") {
      $rows[] = [
        ['data' => $this->t('Warning'), 'header' => TRUE],
        Xss::filter($testItem->warning),
      ];
    }

    if ($testItem->if_vulnerability == 0 || $testItem->if_vulnerability == 1) {
      $vulnerabilityMarkup = "<h3>Listed Vulnerabilitites</h3>";
      if ($testItem->type == 'composer') {
        $vulnerabilityInfo = $this->getPackagistClient->getVulnerabilities($testItem->vendor, strtolower($testItem->product));
        $vulnerabilityMarkup = $this->getVulnerabilityMarkup($vulnerabilityInfo['advisories'][$testItem->vendor . "/" . strtolower($testItem->product)]);
      }
      $rows[] = [
        ['data' => $this->t('Vulnerability Report'), 'header' => TRUE],
        Markup::create($vulnerabilityMarkup),
      ];
    }

    $build['vulnerability_test_item_table'] = [
      '#type' => 'table',
      '#rows' => $rows,
    ];

    return $build;
  }

  /**
   * Builds a markup string for vulnerabilities.
   *
   * @param mixed $vulnerabilities
   *   The vulnerabilitites to be made into markup.
   *
   * @return string
   *   Vulnerabilitites as a markup string
   */
  private function getVulnerabilityMarkup($vulnerabilities) {
    $vulnerabilityMarkup = "";
    if (isset($vulnerabilities)) {
      if (count($vulnerabilities) > 0) {
        foreach ($vulnerabilities as $item) {
          $advisoryId = Xss::filter($item['advisoryId']);
          $vulnerabilityMarkup .= "<p><b>advisoryId:</b> {$advisoryId}</p>";
          $packageName = Xss::filter($item['packageName']);
          $vulnerabilityMarkup .= "<p><b>packageName:</b> {$packageName}</p>";
          $remoteId = Xss::filter($item['remoteId']);
          $vulnerabilityMarkup .= "<p><b>remoteId:</b> {$remoteId}</p>";
          $title = Xss::filter($item['title']);
          $vulnerabilityMarkup .= "<p><b>title:</b> {$title}</p>";
          $link = Link::fromTextAndUrl(
            $item['link'],
            Url::fromUri($item['link'])
          )->toString();
          $vulnerabilityMarkup .= $link;
          $cve = Xss::filter($item['cve']);
          $vulnerabilityMarkup .= "<p><b>cve:</b> {$cve}</p>";
          $affectedVersions = Xss::filter($item['affectedVersions']);
          $vulnerabilityMarkup .= "<p><b>affectedVersions:</b> {$affectedVersions}</p>";
          $source = UrlHelper::filterBadProtocol($item['source']);
          $vulnerabilityMarkup .= "<p><b>source:</b> {$source}</p>";
          $reportedAt = Xss::filter($item['reportedAt']);
          $vulnerabilityMarkup .= "<p><b>reportedAt:</b> {$reportedAt}</p>";
          $composerRepository = UrlHelper::filterBadProtocol($item['composerRepository']);
          $vulnerabilityMarkup .= "<p><b>composerRepository:</b> {$composerRepository}</p>";
          $severity = Xss::filter($item['severity']);
          $vulnerabilityMarkup .= "<p><b>severity:</b> {$severity}</p><br />";
        }
      }
    }

    return $vulnerabilityMarkup;
  }

  /**
   * Builds a query for database log administration filters based on session.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   *
   * @return array|null
   *   An associative array with keys 'where' and 'args' or NULL if there were
   *   no filters set.
   */
  private function buildFilterQuery(Request $request) {
    $session_filters = $request->getSession()->get('list_packages_overview_filter', []);
    if (empty($session_filters)) {
      return;
    }

    $this->moduleHandler()->loadInclude('list_packages', 'admin.inc');

    $filters = list_packages_filters();

    // dd($filters);
    // Build query.
    $where = $args = [];
    foreach ($session_filters as $key => $filter) {
      if ($key != 'action' && $filter != "") {
        $filter_where = [];
        $filter_where[] = $filters[$key]['where'];
        $args[] = $filter;

        if (!empty($filter_where)) {
          $where[] = '(' . implode(' OR ', $filter_where) . ')';
        }
      }
    }
    $where = !empty($where) ? implode(' AND ', $where) : '';

    return [
      'where' => $where,
      'args' => $args,
    ];
  }

}
